@@ -1,29 +1,28 @@
+# -*- coding: utf-8 -*-
 
-## Copyright 2015-2021 PyPSA Developers
-
-## You can find the list of PyPSA Developers at
-## https://pypsa.readthedocs.io/en/latest/developers.html
-
-## PyPSA is released under the open source MIT License, see
-## https://github.com/PyPSA/PyPSA/blob/master/LICENSE.txt
-
-"""Functionality to help with georeferencing and calculate
-distances/areas.
 
+"""
+Functionality to help with georeferencing and calculate distances/areas.
 """
 
-__author__ = "PyPSA Developers, see https://pypsa.readthedocs.io/en/latest/developers.html"
-__copyright__ = ("Copyright 2015-2021 PyPSA Developers, see https://pypsa.readthedocs.io/en/latest/developers.html, "
-                 "MIT License")
+__author__ = (
+    "PyPSA Developers, see https://pypsa.readthedocs.io/en/latest/developers.html"
+)
+__copyright__ = (
+    "Copyright 2015-2022 PyPSA Developers, see https://pypsa.readthedocs.io/en/latest/developers.html, "
+    "MIT License"
+)
+
+import logging
 
 import numpy as np
 
-import logging
 logger = logging.getLogger(__name__)
 
+
 def haversine_pts(a, b):
     """
-    Determines crow-flies distance between points in a and b
+    Determines crow-flies distance between points in a and b.
 
     ie. distance[i] = crow-fly-distance between a[i] and b[i]
 
@@ -45,9 +44,12 @@ def haversine_pts(a, b):
     lon0, lat0 = np.deg2rad(np.asarray(a, dtype=float)).T
     lon1, lat1 = np.deg2rad(np.asarray(b, dtype=float)).T
 
-    c = (np.sin((lat1-lat0)/2.)**2 + np.cos(lat0) * np.cos(lat1) *
-         np.sin((lon0 - lon1)/2.)**2)
-    return 6371.000 * 2 * np.arctan2( np.sqrt(c), np.sqrt(1-c) )
+    c = (
+        np.sin((lat1 - lat0) / 2.0) ** 2
+        + np.cos(lat0) * np.cos(lat1) * np.sin((lon0 - lon1) / 2.0) ** 2
+    )
+    return 6371.000 * 2 * np.arctan2(np.sqrt(c), np.sqrt(1 - c))
+
 
 def haversine(a, b):
     """
@@ -91,5 +93,4 @@ def haversine(a, b):
     a = ensure_dimensions(a)
     b = ensure_dimensions(b)
 
-    return haversine_pts(a[np.newaxis,:], b[:,np.newaxis])
-
+    return haversine_pts(a[np.newaxis, :], b[:, np.newaxis])
